@@ -41,6 +41,7 @@ FROM
     FULL OUTER JOIN b USING (c);
 
 CREATE TYPE jwt_token AS (
-    token TEXT, field: TEXT
+    token TEXT,
+    field: TEXT
 );
 
