@@ -18,7 +18,7 @@ SET check_function_bodies = FALSE;
 
 SET client_min_messages = warning;
 
-SET row_security = off;
+SET row_security = OFF;
 
 --
 -- Name: plpgsql; Type: EXTENSION; Schema: -; Owner:
@@ -153,7 +153,7 @@ BEGIN
                     round(random() * 12) + 6 INTO v_nombre;
                 -- insertion dans la table de stock
                 INSERT INTO stock (vin_id, contenant_id, annee, nombre)
-                    VALUES (v_vin_id, v_contenant_id, v_annee, v_nombre);
+                VALUES (v_vin_id, v_contenant_id, v_annee, v_nombre);
                 IF (((compteur % 1000) = 0) OR (compteur = tuples_a_generer)) THEN
                     raise notice 'stock : % sur % tuples generes', compteur, tuples_a_generer;
                 END IF;
@@ -217,7 +217,7 @@ BEGIN
             FOR v_type_vin_id IN 1..types_vins LOOP
                 -- insertion dans la table de vin
                 INSERT INTO vin (recoltant_id, appellation_id, type_vin_id)
-                    VALUES (v_recoltant_id, v_appellation_id, v_type_vin_id);
+                VALUES (v_recoltant_id, v_appellation_id, v_type_vin_id);
                 IF (((compteur % 1000) = 0) OR (compteur = tuples_a_generer)) THEN
                     raise notice 'vins : % sur % tuples generes', compteur, tuples_a_generer;
                 END IF;
@@ -372,7 +372,7 @@ CREATE TABLE appellation (
     region_id integer
 )
 WITH (
-    autovacuum_enabled = off
+    autovacuum_enabled = OFF
 );
 
 ALTER TABLE appellation OWNER TO userdb;
@@ -406,7 +406,7 @@ CREATE TABLE contenant (
     libelle text
 )
 WITH (
-    autovacuum_enabled = off,
+    autovacuum_enabled = OFF,
     fillfactor = '20'
 );
 
@@ -441,7 +441,7 @@ CREATE TABLE recoltant (
     adresse text
 )
 WITH (
-    autovacuum_enabled = off
+    autovacuum_enabled = OFF
 );
 
 ALTER TABLE recoltant OWNER TO userdb;
@@ -474,7 +474,7 @@ CREATE TABLE region (
     libelle text NOT NULL
 )
 WITH (
-    autovacuum_enabled = off
+    autovacuum_enabled = OFF
 );
 
 ALTER TABLE region OWNER TO userdb;
@@ -509,7 +509,7 @@ CREATE TABLE stock (
     nombre integer NOT NULL
 )
 WITH (
-    autovacuum_enabled = off
+    autovacuum_enabled = OFF
 );
 
 ALTER TABLE stock OWNER TO userdb;
@@ -523,7 +523,7 @@ CREATE TABLE type_vin (
     libelle text NOT NULL
 )
 WITH (
-    autovacuum_enabled = off
+    autovacuum_enabled = OFF
 );
 
 ALTER TABLE type_vin OWNER TO userdb;
@@ -558,7 +558,7 @@ CREATE TABLE vin (
     type_vin_id integer NOT NULL
 )
 WITH (
-    autovacuum_enabled = off
+    autovacuum_enabled = OFF
 );
 
 ALTER TABLE vin OWNER TO userdb;
@@ -586,37 +586,43 @@ ALTER SEQUENCE vin_id_seq OWNED BY vin.id;
 -- Name: appellation id; Type: DEFAULT; Schema: public; Owner: userdb
 --
 
-ALTER TABLE ONLY appellation ALTER COLUMN id SET DEFAULT nextval('appellation_id_seq'::regclass);
+ALTER TABLE ONLY appellation
+    ALTER COLUMN id SET DEFAULT nextval('appellation_id_seq'::regclass);
 
 --
 -- Name: contenant id; Type: DEFAULT; Schema: public; Owner: userdb
 --
 
-ALTER TABLE ONLY contenant ALTER COLUMN id SET DEFAULT nextval('contenant_id_seq'::regclass);
+ALTER TABLE ONLY contenant
+    ALTER COLUMN id SET DEFAULT nextval('contenant_id_seq'::regclass);
 
 --
 -- Name: recoltant id; Type: DEFAULT; Schema: public; Owner: userdb
 --
 
-ALTER TABLE ONLY recoltant ALTER COLUMN id SET DEFAULT nextval('recoltant_id_seq'::regclass);
+ALTER TABLE ONLY recoltant
+    ALTER COLUMN id SET DEFAULT nextval('recoltant_id_seq'::regclass);
 
 --
 -- Name: region id; Type: DEFAULT; Schema: public; Owner: userdb
 --
 
-ALTER TABLE ONLY region ALTER COLUMN id SET DEFAULT nextval('region_id_seq'::regclass);
+ALTER TABLE ONLY region
+    ALTER COLUMN id SET DEFAULT nextval('region_id_seq'::regclass);
 
 --
 -- Name: type_vin id; Type: DEFAULT; Schema: public; Owner: userdb
 --
 
-ALTER TABLE ONLY type_vin ALTER COLUMN id SET DEFAULT nextval('type_vin_id_seq'::regclass);
+ALTER TABLE ONLY type_vin
+    ALTER COLUMN id SET DEFAULT nextval('type_vin_id_seq'::regclass);
 
 --
 -- Name: vin id; Type: DEFAULT; Schema: public; Owner: userdb
 --
 
-ALTER TABLE ONLY vin ALTER COLUMN id SET DEFAULT nextval('vin_id_seq'::regclass);
+ALTER TABLE ONLY vin
+    ALTER COLUMN id SET DEFAULT nextval('vin_id_seq'::regclass);
 
 --
 -- Name: appellation appellation_libelle_key; Type: CONSTRAINT; Schema: public; Owner: userdb
